contains method
Contains checks whether a node is contained in this component. Can only be used by StringComponent if the component has been attached.
Implementation
@nonVirtual
bool contains(Node node) {
return elem.contains(node);
}
Contains checks whether a node is contained in this component. Can only be used by StringComponent if the component has been attached.
@nonVirtual
bool contains(Node node) {
return elem.contains(node);
}